Where to find things - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Where to find things

## Locations

Here is a summary of the layout for the different install methods, along with the symbolic names used for each role. These names are used throughout the documentation.

Note

The install locations below are relative to `WEEWX_ROOT`. See Python's documentation on `os.path.join()` for the results of joining two absolute paths (summary: the 2nd path wins).

Debian RedHat/openSUSE Pip (including macOS)

Role | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `/`
Executables | `BIN_ROOT` | `/usr/share/weewx/`
Configuration directory | `CONFIG_ROOT` | `/etc/weewx/`
Skins and templates | `SKIN_ROOT` | `/etc/weewx/skins/`
SQLite databases | `SQLITE_ROOT` | `/var/lib/weewx/`
Web pages and images | `HTML_ROOT` | `/var/www/html/weewx/`
Documentation | `DOC_ROOT` | `/usr/share/doc/weewx/`
Examples | `EXAMPLE_ROOT` | `/usr/share/doc/weewx/examples/`
User directory | `USER_ROOT` | `/usr/share/weewx/user`

Role | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `/`
Executables | `BIN_ROOT` | `/usr/share/weewx/`
Configuration directory | `CONFIG_ROOT` | `/etc/weewx/`
Skins and templates | `SKIN_ROOT` | `/etc/weewx/skins/`
SQLite databases | `SQLITE_ROOT` | `/var/lib/weewx/`
Web pages and images | `HTML_ROOT` | `/var/www/html/weewx/`
Documentation | `DOC_ROOT` | `/usr/share/doc/weewx-x.y.z/`
Examples | `EXAMPLE_ROOT` | `/usr/share/doc/weewx-x.y.z/examples/`
User directory | `USER_ROOT` | `/usr/share/weewx/user`

Role | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `~/weewx-data`
Executables | `BIN_ROOT` | see below
Configuration directory | `CONFIG_ROOT` | `./`
Skins and templates | `SKIN_ROOT` | `./skins/`
SQLite databases | `SQLITE_ROOT` | `./archive/`
Web pages and images | `HTML_ROOT` | `./public_html/`
Documentation | `DOC_ROOT` | `./docs`
Examples | `EXAMPLE_ROOT` | `./examples/`
User directory | `USER_ROOT` | `./bin/user`

## Location of pip-installed executables

If you use a pip install, the location of the executables will depend on the details:

Install method | Commands | Location of executables
--- | --- | ---
pip, no sudo, with `--user` (recommended) | `pip3 install weewx --user` | `~/.local/bin/`
pip, no sudo, no `--user` | `pip3 install weewx` | `~/.local/bin/`
pip with sudo (not recommended) | `sudo pip3 install weewx` | `/usr/local/bin/` (1)
Virtual environment | `python3 -m venv ve` `. ve/bin/activate` `pip3 install weewx` | `./ve/bin/`
Virtual environment with `--user` | `python3 -m venv ve` `. ve/bin/activate` `pip3 install weewx --user` | Not allowed

(1) Checked on Ubuntu 22.02 and Rocky v9.1

## Log files

Where to find your log file. You may require root permissions to read them.

Debian RedHat/openSUSE macOS

`/var/log/syslog`

`/var/log/messages`

The macOS log file is nominally found at `/var/log/syslog`. However, it is likely to contain only severe log messages. You may want to consider logging to a rotating file. See the wiki article Logging to rotating files.